package main

import (
	"encoding/json"
	"fmt"
	"log"
	"net/http"
	"strings"
	"time"
)

type Item struct {
	ID    int    `json:"id"`
	Name  string `json:"name"`
	Price int    `json:"price"`
}

var mapItems = map[string]Item{
	"1": {ID: 1, Name: "koko", Price: 100},
	"2": {ID: 2, Name: "coco", Price: 200},
}

var j = []byte(`[{"id":1,"name":"koko","price":100},{"id":2,"name":"coco","price":200}]`)

func HelloFunc(w http.ResponseWriter, r *http.Request) {
	fmt.Fprintf(w, "Hello World! %s", time.Now())
}

func getItemsHandler(w http.ResponseWriter, r *http.Request) {
	var items []Item
	err := json.Unmarshal(j, &items)
	if err != nil {
		fmt.Println(err)
		http.Error(w, "Internal Server Error", http.StatusInternalServerError)
		return
	}
	enc := json.NewEncoder(w)
	enc.Encode(items)
}

func getItemHandler(w http.ResponseWriter, r *http.Request) {
	id := r.PathValue("id")
	int_id := strings.Split(id, "=")[1]

	item := mapItems[int_id]
	enc := json.NewEncoder(w)
	enc.Encode(item)
}


func main() {
	mux := http.NewServeMux()
	mux.HandleFunc("/", HelloFunc)

	mux.HandleFunc("GET /items", getItemsHandler)

	mux.HandleFunc("GET /items/{id}", getItemHandler)

	server := &http.Server{
		Addr:         ":8080",
		Handler:      mux,
		ReadTimeout:  20 * time.Second,
		WriteTimeout: 20 * time.Second,
	}

	fmt.Println("start server...")
	log.Fatal(server.ListenAndServe())
}
