package main

import (
	"encoding/json"
	"log"
	"net"
	"net/http"
	"net/url"
	"strconv"
	"time"

	"github.com/gocolly/colly/v2"
)

func main() {

	c := colly.NewCollector(
		// Configuration
		// https://godoc.org/github.com/gocolly/colly#Collector
		colly.AllowedDomains("www.bilibili.com", "api.bilibili.com"),
		colly.MaxDepth(3),
	)
	c2 := c.Clone()
	// HTTP configuration
	c.WithTransport(&http.Transport{
		Proxy: http.ProxyFromEnvironment,
		DialContext: (&net.Dialer{
			Timeout:   30 * time.Second, // 超时时间
			KeepAlive: 30 * time.Second, // keepAlive 超时时间
			DualStack: true,
		}).DialContext,
		MaxIdleConns:          100,              // 最大空闲连接数
		IdleConnTimeout:       90 * time.Second, // 空闲连接超时
		TLSHandshakeTimeout:   10 * time.Second, // TLS 握手超时
		ExpectContinueTimeout: 1 * time.Second,
	})

	// 在请求前调用
	c.OnRequest(func(r *colly.Request) {
		r.Headers.Add("authority", "api.bilibili.com")
		r.Headers.Add("accept", "application/json, text/plain, */*")
		r.Headers.Add("accept-language", "en")
		r.Headers.Add("cookie", "b_lsid=CE5D91BA_18DBBAE42FB; _uuid=EBD510748-4368-4CA10-33106-1535B65F99BD76325infoc; buvid_fp=cf3761d6fa55fab80e5bc8dd44bc73c5; buvid3=A63B588A-ECC7-A9ED-2649-322E8F3DF36E75931infoc; b_nut=1708250776; buvid4=8CBA4D0B-F576-8DDE-9A75-BB0B19A1F5E475931-024021810-71Lmdf6eyFJyG5DAz4rYYA%3D%3D")
		r.Headers.Add("origin", "https://www.bilibili.com")
		r.Headers.Add("referer", "https://www.bilibili.com/guochuang/index/?from_spmid=666.5.index.0")
		r.Headers.Add("sec-ch-ua", "\"Not A(Brand\";v=\"99\", \"Google Chrome\";v=\"121\", \"Chromium\";v=\"121\"")
		r.Headers.Add("sec-ch-ua-mobile", "?0")
		r.Headers.Add("sec-ch-ua-platform", "\"Windows\"")
		r.Headers.Add("sec-fetch-dest", "empty")
		r.Headers.Add("sec-fetch-mode", "cors")
		r.Headers.Add("sec-fetch-site", "same-site")
		r.Headers.Add("user-agent", "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/121.0.0.0 Safari/537.36")

		u := url.Values{
			"st":             []string{"4"},
			"order":          []string{"3"},
			"season_version": []string{"-1"},
			"is_finish":      []string{"-1"},
			"copyright":      []string{"-1"},
			"season_status":  []string{"-1"},
			"year":           []string{"-1"},
			"style_id":       []string{"-1"},
			"sort":           []string{"0"},
			"page":           []string{"1"},
			"season_type":    []string{"4"},
			"pagesize":       []string{"20"},
			"type":           []string{"1"},
		}
		r.URL.RawQuery = u.Encode()

	})

	// 在请求后调用
	c.OnResponse(func(r *colly.Response) {

		var bili map[string]interface{}
		err := json.Unmarshal(r.Body, &bili)
		if err != nil {
			log.Fatal("Error parsing JSON:", err)
		}

		list := bili["data"].(map[string]interface{})["list"].([]interface{})
		media_id := list[0].(map[string]interface{})["media_id"].(float64)

		// r.Ctx.Put("media_id", media_id)

		rawURL := "https://www.bilibili.com/bangumi/media/"
		mid := strconv.FormatFloat(media_id, 'f', -1, 64)
		uri, _ := url.JoinPath(rawURL, "md"+mid)
		
		c2.Visit(uri)
	},
	)

	c2.OnRequest(func(r *colly.Request) {
		r.Headers.Add("authority", "www.bilibili.com")
		r.Headers.Add("accept", "text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.7")
		r.Headers.Add("accept-language", "en")
		r.Headers.Add("cache-control", "max-age=0")
		r.Headers.Add("cookie", "b_lsid=B9F8C4FF_18DBBD21BD8; _uuid=E1010252B2-829C-8CB10-F76B-553F26D586E225604infoc; buvid3=195D9A4D-2C90-80B2-9DE7-BCB3E9F915FF25499infoc; b_nut=1708253126; buvid4=BB0D503C-3F42-0C6E-1DB2-4B77337CEC4B25499-024021810-71Lmdf6eyFJyG5DAz4rYYA%3D%3D; buvid_fp=cf3761d6fa55fab80e5bc8dd44bc73c5")
		r.Headers.Add("sec-ch-ua", "\"Not A(Brand\";v=\"99\", \"Google Chrome\";v=\"121\", \"Chromium\";v=\"121\"")
		r.Headers.Add("sec-ch-ua-mobile", "?0")
		r.Headers.Add("sec-ch-ua-platform", "\"Windows\"")
		r.Headers.Add("sec-fetch-dest", "document")
		r.Headers.Add("sec-fetch-mode", "navigate")
		r.Headers.Add("sec-fetch-site", "none")
		r.Headers.Add("sec-fetch-user", "?1")
		r.Headers.Add("upgrade-insecure-requests", "1")
		r.Headers.Add("user-agent", "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/121.0.0.0 Safari/537.36")

	})

	c2.OnResponse(func(r *colly.Response) {
		log.Println(string(r.Body))
	})

	c.Visit("https://api.bilibili.com/pgc/season/index/result")

}
