package std

import (
	"database/sql"
	"fmt"
	"testing"
	"time"

	_ "github.com/go-sql-driver/mysql"
)

var db *sql.DB

func initDB(dsn string) (err error) {
	db, err = sql.Open("mysql", dsn)
	if err != nil {
		return err
	}

	err = db.Ping()
	if err != nil {
		return err
	}

	// See "Important settings" section.
	db.SetConnMaxLifetime(time.Minute * 3)
	db.SetMaxOpenConns(10)
	db.SetMaxIdleConns(10)
	fmt.Println("数据库连接成功")
	return

}

// 查询

// 查找一条数据
type Users struct {
	Uid    int32
	Uname  string
	Upwd   string
	Uemail sql.NullString
}

func GetUsers(id int) (Users, error) {
	q := "SELECT uid, uname, upwd, uemail FROM users WHERE uid=?"

	// QueryRow 返回一行数据
	// QueryRow总是返回非nil的值，直到返回值的Scan方法被调用时，才会返回被延迟的错误。（如：未找到结果）
	row := db.QueryRow(q, id)

	var u Users
	// 在QueryRow后要调用Scan方法，不然数据库连接不会被释放
	err := row.Scan(&u.Uid, &u.Uname, &u.Upwd, &u.Uemail)
	if err != nil {
		fmt.Println("数据读取失败. err:", err)
	}
	return u, err
}

// 查找多条数据
type MultUsers struct {
	Uid    int32
	Uname  string
	Upwd   string
	Uemail sql.NullString
}

func ListUsers(id int) ([]MultUsers, error) {
	q := "SELECT uid, uname, upwd, uemail FROM users"
	rows, err := db.Query(q)
	if err != nil {
		return nil, err
	}

	// 调用 Close 释放数据库连接
	defer rows.Close()

	var items []MultUsers

	for rows.Next() {
		var i MultUsers
		// 每次调用Rows.Scan时，即使是第一次，都必须先调用 Rows.Next
		if err := rows.Scan(
			&i.Uid,
			&i.Uname,
			&i.Upwd,
			&i.Uemail,
		); err != nil {
			return nil, err
		}
		items = append(items, i)
	}
	if err := rows.Close(); err != nil {
		return nil, err
	}
	if err := rows.Err(); err != nil {
		return nil, err
	}
	return items, nil

}

// 插入数据
func CreateUsers() {
	// q := "insert uid, uname, upwd, uemail FROM users"
}

func TestQuickStart(t *testing.T) {
	dsn := "root:123456@tcp(127.0.0.1:3306)/onlinedb"
	err := initDB(dsn)
	if err != nil {
		fmt.Println("数据库初始化失败. err:", err)
		return
	}

	item, err := GetUsers(1)
	if err != nil {
		fmt.Println(err)
	}
	fmt.Printf("%#v\n", item)

	items, err := ListUsers(3)
	if err != nil {
		fmt.Println(err)
	}
	fmt.Printf("%#v\n", items[:1])
}
