package encoding

import (
	"encoding/json"
	"fmt"
	"testing"
)

func TestQickStart(t *testing.T) {
	// marshal
	type ColorGroup struct {
		ID     int
		Name   string
		Colors []string
	}

	group := ColorGroup{
		ID:     1,
		Name:   "Reds",
		Colors: []string{"Cromson", "Red", "Ruby", "Maroon"},
	}

	b, err := json.Marshal(group)

	if err != nil {
		fmt.Println("error:", err)
	}
	fmt.Printf("%q\n", b)

	// unmarshal
	type Color struct {
		Space string
		Point json.RawMessage // delay parsing until we know the color space
	}

	var j = []byte(`[
	{"Space": "YCbCr", "Point": {"Y": 255, "Cb": 0, "Cr": -10}},
	{"Space": "RGB",   "Point": {"R": 98, "G": 218, "B": 255}}]`)
	var colors []Color
	err = json.Unmarshal(j, &colors)
	if err != nil {
		fmt.Println(err)
	}
	fmt.Printf("%q\n", colors)

}

// go sturct encode to json
func TestMarshal(t *testing.T) {
	// json.Marshal 会忽略未导出字段(即小写字段)，要忽略其他字段可以用标签 "-"，如`json:"-"`
	type User struct {
		UserName string `json:"user_name"` // 编码时将 UserName 转换为 user_name
		PassWord string `json:"password"`
		Email    string `json:"email,omitempty"` // omitempty 忽略空值字段 （当Email为空时，输出将不带有Email）
	}

	user := User{
		UserName: "koko",
		PassWord: "xxxxxxxxxx",
		Email:    "example@gmail.com",
	}

	u, err := json.Marshal(user)
	if err != nil {
		fmt.Println(err)
	}
	fmt.Println(string(u))
}
