package math

import (
	"fmt"
	"math/rand"
	"strings"
	"testing"
	"time"
)

// 生成随机不同类型的数字
func TestRandomNumber(t *testing.T) {
	// Float
	fmt.Println(rand.Float32())    // 0.7050946
	fmt.Println(rand.Float64())    // 0.658687518790183
	fmt.Println(rand.ExpFloat64()) // 0.3075637554450086

	// Int
	fmt.Println(rand.Int()) // 128851467994200148

	const i32 = 99
	fmt.Println(rand.Int31())     // 74400753
	fmt.Println(rand.Int31n(i32)) // 63

	const i64 = 100
	fmt.Println(rand.Int63())     // 5710464865807547219
	fmt.Println(rand.Int63n(i64)) // 84
	fmt.Println(rand.Intn(100))   // 81

	// Uint
	fmt.Println("Uint32:", rand.Uint32()) // Uint32: 2715105603
	fmt.Println("Uint64:", rand.Uint64()) // Uint64: 16603356168297960621
}

// 生成 0-n 个长度且值不重复的伪随机切片
func TestPerm(t *testing.T) {
	n := 10
	fmt.Println(rand.Perm(n)) // [8 2 4 5 3 7 6 1 9 0]
}

// 随机交换函数，n 是元素的数量，i, j 是元素的索引
func TestShuffle(t *testing.T) {

	strRaw := "ink runs from the corners of my mouth"
	strSlice := strings.Fields(strRaw)

	swapFn := func(i, j int) {
		strSlice[i], strSlice[j] = strSlice[j], strSlice[i]
	}
	rand.Shuffle(len(strSlice), swapFn)

	fmt.Println(strSlice)

}

func TestSturct(t *testing.T) {
	seed := time.Now().UnixNano() // 给定不同的种子
	src := rand.NewSource(seed)
	r := rand.New(src)
	fmt.Println(r.Int()) // 8747070100365025316
}
