package net

import (
	"bytes"
	"encoding/json"
	"fmt"
	"io"
	"mime/multipart"
	"net/http"
	"net/url"
	"os"
	"strings"
)

var client http.Client

func PrintResp(resp *http.Response) {
	res, err := io.ReadAll(resp.Body)
	if err != nil {
		fmt.Println(err)
	}
	fmt.Printf("%v\n", string(res))
}

// Get
func MethodGet(q string) (resp *http.Response, err error) {
	// Default Method Get
	if q == "" {
		req, err := http.NewRequest(http.MethodGet, "https://httpbin.org/get", nil)
		if err != nil {
			return nil, err
		}
		resp, err = client.Do(req)
		if err != nil {
			return resp, err
		}
		// Method Get query params
	} else if q == "query" {
		req, err := http.NewRequest(http.MethodGet, "https://httpbin.org/get", nil)
		if err != nil {
			return nil, err
		}
		// url query params format
		// url = "https://httpbin.org/get?url=url.Value"
		url := url.Values{}
		url.Add("url", "url.Values")
		req.URL.RawQuery = url.Encode()

		resp, err = client.Do(req)
		if err != nil {
			return resp, err
		}
	}
	return resp, err
}

// Post
func MethodPost(data string) (resp *http.Response, err error) {
	uri := "https://httpbin.org/post"

	if data == "form" {
		// form 表单
		contentType := "application/x-www-form-urlencoded"

		form := url.Values{}
		form.Add("username", "koko")
		form.Add("password", "123456")
		payload := strings.NewReader(form.Encode())
		// payload := strings.NewReader("username=koko&password=123456")

		req, err := http.NewRequest(http.MethodPost, uri, payload)
		req.Header.Set("Content-Type", contentType)
		if err != nil {
			return nil, err
		}

		resp, err = client.Do(req)
		return resp, err
	}
	// TODO
	if data == "json" {
		contentType := "application/json"
		// data := struct {
		// 	Username string
		// 	Password string
		// }{
		// 	Username: "koko",
		// 	Password: "123456",
		// }
		data := map[string]string{"username":"koko","pwd":"123456"}
		payload, _ := json.Marshal(data)
		req, err := http.NewRequest(http.MethodPost, uri, bytes.NewReader(payload))
		req.Header.Set("Content-Type", contentType)
		
		if err != nil {
			return nil, err
		}

		resp, err = client.Do(req)

		return resp, err
	}

	return resp, err
}

func MethodPostFiles() (resp *http.Response, err error) {
	    // 打开要上传的文件
		file, err := os.Open("./req_test.go")
		if err != nil {
			fmt.Println("打开文件时出错:", err)
			return
		}
		defer file.Close()
	
		// 创建一个新的多部分写入器
		body := &bytes.Buffer{}
		writer := multipart.NewWriter(body)
	
		// 创建一个表单字段，并将文件写入其中
		part, err := writer.CreateFormFile("file", "./req_test.go")
		if err != nil {
			fmt.Println("创建表单文件时出错:", err)
			return
		}
		_, err = io.Copy(part, file)
		if err != nil {
			fmt.Println("将文件复制到表单中时出错:", err)
			return
		}
	
		// 当完成时关闭多部分写入器
		writer.Close()
	
		// 使用多部分正文创建 POST 请求
		uri := "https://httpbin.org/post"
		req, err := http.NewRequest(http.MethodPost, uri, body)
		if err != nil {
			fmt.Println("创建请求时出错:", err)
			return
		}
		req.Header.Set("Content-Type", writer.FormDataContentType())
	
		// 发送请求
		resp, err = client.Do(req)
		if err != nil {
			fmt.Println("发送请求时出错:", err)
			return
		}
		return
}