package regex

import (
	"fmt"
	"regexp"
)

func intro() {

	/*
		func (re *Regexp) Find(b []byte) []byte
		func (re *Regexp) FindAll(b []byte, n int) [][]byte
		func (re *Regexp) FindAllIndex(b []byte, n int) [][]int
		func (re *Regexp) FindAllString(s string, n int) []string
		func (re *Regexp) FindAllStringIndex(s string, n int) [][]int
		func (re *Regexp) FindAllStringSubmatch(s string, n int) [][]string
		func (re *Regexp) FindAllStringSubmatchIndex(s string, n int) [][]int
		func (re *Regexp) FindAllSubmatch(b []byte, n int) [][][]byte
		func (re *Regexp) FindAllSubmatchIndex(b []byte, n int) [][]int
		func (re *Regexp) FindIndex(b []byte) (loc []int)
		func (re *Regexp) FindReaderIndex(r io.RuneReader) (loc []int)
		func (re *Regexp) FindReaderSubmatchIndex(r io.RuneReader) []int
		func (re *Regexp) FindString(s string) string
		func (re *Regexp) FindStringIndex(s string) (loc []int)
		func (re *Regexp) FindStringSubmatch(s string) []string
		func (re *Regexp) FindStringSubmatchIndex(s string) []int
		func (re *Regexp) FindSubmatch(b []byte) [][]byte
		func (re *Regexp) FindSubmatchIndex(b []byte) []int
	*/

	// Compile 解析正则表达式，若成功则返回一个正则表达式对象
	// func regexp.Compile(expr string) (*regexp.Regexp, error)

	// MustCompile 与 Compile 类似, 但是解析失败后会 panic
	/*
		```go
		func MustCompile(str string) *Regexp {
			regexp, err := Compile(str)
			if err != nil {
				panic(`regexp: Compile(` + quote(str) + `): ` + err.Error())
			}
			return regexp
		}
		```
	*/
	re := regexp.MustCompile(`foo.?`)

	// Find 查找匹配到的第一个值，返回一个字节切片 []byte
	match := re.Find([]byte(`seafood fool`))
	fmt.Printf("%q\n", match) // "food"

	// FindAll 查找匹配到的所有值，返回一个二维字节切片 [][]byte
	// FindAll(b []byte, n int) [][]byte
	// 第二个入参当 n<0 时，匹配符合正则表达式的全部值，当 n>0 时匹配 n 个值
	/*
		```go
		func (re *Regexp) FindAll(b []byte, n int) [][]byte {
			if n < 0 {
				n = len(b) + 1
			}
			var result [][]byte
			re.allMatches("", b, n, func(match []int) {
				if result == nil {
					result = make([][]byte, 0, startSize)
				}
				result = append(result, b[match[0]:match[1]:match[1]])
			})
			return result
		}
		```
	*/
	matchs := re.FindAll([]byte(`seafood fool foox`), -1)
	fmt.Printf("%q\n", matchs) // ["food" "fool" "foox"]
}

// 子匹配字符串查找
func FindStringSubmatchCv() []string {
	re := regexp.MustCompile(`a(x*)b(y|z)c`)
	match := re.FindStringSubmatch("-axxxbyc-")
	return match
}

// 子匹配字符串查找，查找匹配到的所有值
func FindAllStringSubmatchCv() {
	re := regexp.MustCompile(`a(x*)b`)
	fmt.Printf("%q\n", re.FindAllStringSubmatch("-ab-", -1))      // [["ab" ""]]
	fmt.Printf("%q\n", re.FindAllStringSubmatch("-axxb-", -1))    // [["axxb" "xx"]]
	fmt.Printf("%q\n", re.FindAllStringSubmatch("-ab-axb-", -1))  // [["ab" ""] ["axb" "x"]]
	fmt.Printf("%q\n", re.FindAllStringSubmatch("-axxb-ab-", -1)) // [["axxb" "xx"] ["ab" ""]]
}
