package regex

import (
	"fmt"
	"regexp"
	"testing"
)

func TestIntro(t *testing.T) {
	intro()
}

func TestFindStringSubmatchCv(t *testing.T) {
	match := FindStringSubmatchCv()
	fmt.Printf("%q\n", match)

}

func TestFindAllStringSubmatchCv(t *testing.T) {
	FindAllStringSubmatchCv()
}

func TestExpand(t *testing.T) {
	content := []byte(`
	# comment line
	option1: value1
	option2: value2

	# another comment line
	option3: value3
`)

	// 正则匹配：键值对key：value
	pattern := regexp.MustCompile(`(?m)(?P<key>\w+):\s+(?P<value>\w+)$`)

	//"key: value" 转换为 "key=value"，并引用通过$正则表达式匹配的值
	template := []byte("$key=$value\n")

	result := []byte{}
	for _, submatches := range pattern.FindAllSubmatchIndex(content, -1) {
		// 把匹配到的每个键值对应用到对应模板上
		result = pattern.Expand(result, template, content, submatches)
	}
	fmt.Println(string(result))
}

func TestFindIndex(t *testing.T) {
	content := []byte(`
	# comment line
	option1: value1
	option2: value2
`)
	// 正则表达式从内容中匹配键值对
	pattern := regexp.MustCompile(`(?m)(?P<key>\w+):\s+(?P<value>\w+)$`)

	loc := pattern.FindIndex(content)
	fmt.Println(loc)                            //[18 33]
	fmt.Println(string(content[loc[0]:loc[1]])) //option1: value1
}

func TestReplaceAll(t *testing.T) {
	re := regexp.MustCompile(`a(x*)b`)
	fmt.Printf("%q\n", re.ReplaceAll([]byte("-ab-axxb-"), []byte("T")))     // "-T-T-"
	fmt.Printf("%q\n", re.ReplaceAll([]byte("-ab-axxb-"), []byte("$1")))    // "--xx-"
	fmt.Printf("%q\n", re.ReplaceAll([]byte("-ab-axxb-"), []byte("$1W")))   //  "---"
	fmt.Printf("%q\n", re.ReplaceAll([]byte("-ab-axxb-"), []byte("${1}W"))) // "-W-xxW-"
}
