package slices

import (
	"fmt"
	"slices"
	"testing"
)

func printSlice(s string, x []int) {
	fmt.Printf("%s len=%d cap=%d %v\n",
		s, len(x), cap(x), x)
}

func TestSliceBasicCRUD(t *testing.T) {

	var s []int

	s = []int{1, 2, 3, 4, 5}
	fmt.Printf("slices: %v\n", s)

	// 增
	s = append(s, 6)
	fmt.Printf("slices create: %v\n", s)

	// 改
	s[5] = 7
	fmt.Printf("slices update: %v\n", s)

	// 删
	// s[low:hight]
	s = s[:len(s)-1] // 丢弃最后一个元素
	fmt.Printf("slices delete: %v\n", s)

	// 查
	fmt.Printf("slices read: %v\n", s[0])
}

func TestSlicePKG(t *testing.T) {
	s := make([]int, 5, 7)
	for i := 0; i < 5; i++ {
		s[i] = i + 1
	}
	printSlice("Slices:", s)

	// Clip
	// 从切片中删除未使用的容量(capacity)
	s = slices.Clip(s)
	printSlice("Clip:", s)

	// Clone
	// 浅拷贝
	sclone := slices.Clone(s)
	printSlice("Clone:", sclone)

	// Compact
	// 合并相等的值
	s = slices.Compact(s)
	printSlice("Compact:", s)

	// Contains
	// v 是否包含在 slices 中
	ok := slices.Contains(s, 1)
	fmt.Printf("Contains: %v\n", ok)

	// Delete
	s = slices.Delete(s, 1, 4) // 删除索引 [1, 4) 之间的元素
	printSlice("Delete:", s)

	// Equel
	ok = slices.Equal(s, []int{1, 5})
	fmt.Printf("Equal: %v\n", ok)

	// Index
	// 查找 slices 中值相等的元素，返回其索引 index 
	idx := slices.Index(s, 5)
	fmt.Printf("Index: %v\n", idx)

	// Insert
	s = slices.Insert(s, 1, 2)
	printSlice("Insert:", s)

	// Max and Min
	// slices 中最大的数
	max := slices.Max(s)
	min := slices.Min(s)
	fmt.Printf("Max:%v Min:%v\n", max, min)

	// Reverse 
	// Sort 
	// Replace 
	// BinarySearch
}	
