package string

import (
	"fmt"
	"strconv"
	"testing"
)

func TestAppendAny(t *testing.T) {
	// AppendBool
	b := []byte("bool:")
	b = strconv.AppendBool(b, true)
	fmt.Println(string(b)) //bool:true

	// AppendFloat
	b32 := []byte("float32:")
	b32 = strconv.AppendFloat(b32, 3.1415926535, 'E', -1, 32)
	fmt.Println(string(b32)) // float32:3.1415927E+00

	b64 := []byte("float64:")
	b64 = strconv.AppendFloat(b64, 3.1415926535, 'E', -1, 64)
	fmt.Println(string(b64))

	// AppendInt
	b10 := []byte("int (base 10):")
	b10 = strconv.AppendInt(b10, -42, 10)
	fmt.Println(string(b10))

	b16 := []byte("int (base 16):")
	b16 = strconv.AppendInt(b16, -42, 16)
	fmt.Println(string(b16))

}

func TestAtioAndItoa(t *testing.T) {
	// Atio
	v := "10"
	if s, err := strconv.Atoi(v); err == nil {
		fmt.Printf("%T, %v", s, s) // int, 10
	}

	// Itoa
	i := 10
	s := strconv.Itoa(i)
	fmt.Printf("%T, %v\n", s, s) // string, 10
}

func TestFormat(t *testing.T) {
	// FormatBool
	v := true
	s := strconv.FormatBool(v)
	fmt.Printf("%T, %v\n", s, s) // string, true

	// FormatFloat
	v1 := 3.1415926535
	s32 := strconv.FormatFloat(v1, 'E', -1, 32)
	fmt.Printf("%T, %v\n", s32, s32)

	s64 := strconv.FormatFloat(v1, 'E', -1, 64)
	fmt.Printf("%T, %v\n", s64, s64)

	fmt64 := strconv.FormatFloat(v1, 'g', -1, 64)
	fmt.Printf("%T, %v\n", fmt64, fmt64)

	// FormatInt
	v2 := int64(-42)

	s10 := strconv.FormatInt(v2, 10)
	fmt.Printf("%T, %v\n", s10, s10)

	s16 := strconv.FormatInt(v2, 16)
	fmt.Printf("%T, %v\n", s16, s16)
}

func TestParse(t *testing.T) {
	// ParseBool
	v := "true"
	if s, err := strconv.ParseBool(v); err == nil {
		fmt.Printf("%T, %v\n", s, s)
	}
}

// 输出转义符号
func TestQuote(t *testing.T) {
	originalString := "Hello, \"World\"!"

	// 使用 strconv.Quote 将字符串转为带有双引号的字面值
	quotedString := strconv.Quote(originalString)

	fmt.Printf("Original: %s\n", originalString)
	fmt.Printf("Quoted: %s\n", quotedString)
}
