package time

import (
	"fmt"
	"testing"
	"time"
)

// const (
// 	Layout      = "01/02 03:04:05PM '06 -0700" // The reference time, in numerical order.
// 	ANSIC       = "Mon Jan _2 15:04:05 2006"
// 	UnixDate    = "Mon Jan _2 15:04:05 MST 2006"
// 	RubyDate    = "Mon Jan 02 15:04:05 -0700 2006"
// 	RFC822      = "02 Jan 06 15:04 MST"
// 	RFC822Z     = "02 Jan 06 15:04 -0700" // RFC822 with numeric zone
// 	RFC850      = "Monday, 02-Jan-06 15:04:05 MST"
// 	RFC1123     = "Mon, 02 Jan 2006 15:04:05 MST"
// 	RFC1123Z    = "Mon, 02 Jan 2006 15:04:05 -0700" // RFC1123 with numeric zone
// 	RFC3339     = "2006-01-02T15:04:05Z07:00"
// 	RFC3339Nano = "2006-01-02T15:04:05.999999999Z07:00"
// 	Kitchen     = "3:04PM"
// 	// Handy time stamps.
// 	Stamp      = "Jan _2 15:04:05"
// 	StampMilli = "Jan _2 15:04:05.000"
// 	StampMicro = "Jan _2 15:04:05.000000"
// 	StampNano  = "Jan _2 15:04:05.000000000"
// 	DateTime   = "2006-01-02 15:04:05"
// 	DateOnly   = "2006-01-02"
// 	TimeOnly   = "15:04:05"
// )

// const (
// 	Nanosecond  Duration = 1
// 	Microsecond          = 1000 * Nanosecond
// 	Millisecond          = 1000 * Microsecond
// 	Second               = 1000 * Millisecond // 1 秒
// 	Minute               = 60 * Second        // 1 分钟
// 	Hour                 = 60 * Minute        // 1 小时
// )

// Sleep
func TestSleep(t *testing.T) {
	time.Sleep(time.Second)
	fmt.Printf("%q", time.Second) // "1s"
}

// Time Struct

// Date 按照参数构造
func TestTimeFunc(t *testing.T) {
	// Date
	t1 := time.Date(2009, time.November, 10, 23, 0, 0, 0, time.UTC)
	fmt.Printf("Go launched at %s\n", t1.Local()) // Go launched at 2009-11-11 07:00:00 +0800 CST

	// Now
	t2 := time.Now()
	fmt.Println("Now:", t2) // 2024-01-26 13:32:28.077423233 +0800 CST m=+0.000328401

	// Parse
	const longForm = "Jan 2, 2006 at 3:04pm (MST)"
	t3, _ := time.Parse(longForm, "Feb 3, 2013 at 7:54pm (PST)")
	fmt.Println("Parse:", t3) // Parse: 2013-02-03 19:54:00 +0000 PST

	t3, _ = time.Parse(time.RFC3339, "2006-01-02T15:04:05Z")
	fmt.Println("Parse:", t3) // Parse: 2006-01-02 15:04:05 +0000 UTC

	// Unix
	unixTime := time.Date(2009, time.November, 10, 23, 0, 0, 0, time.UTC)
	fmt.Println("timeStamp:", unixTime.Unix()) // timeStamp: 1257894000
	t4 := time.Unix(unixTime.Unix(), 0).UTC()
	fmt.Println("Unix:", t4) // Unix: 2009-11-10 23:00:00 +0000 UTC

	unixTime = time.Now()
	timeStamp := unixTime.Unix()
	t4 = time.Unix(timeStamp, 0).UTC()
	fmt.Println("Unix-Now:", t4) // Unix-Now: 2024-01-26 05:43:41 +0000 UTC
}
